# -*- coding: utf-8 -*-
# Generated by Django 1.11.6 on 2017-10-11 15:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mbills', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='mbillstransaction',
            name='status',
            field=models.IntegerField(choices=[(-5, 'Failed'), (-4, 'Recurring Cancelled'), (-3, 'Insufficient Funds'), (-2, 'Timed Out'), (-1, 'Rejected'), (0, 'Accepted'), (1, 'Pending'), (2, 'Authorized'), (3, 'Paid'), (4, 'Voided')], default=0),
        ),
    ]
